<?php

namespace Drupal\cacheprofiler\Renderer;

use Drupal\cacheprofiler\DataCollector\CacheProfilerDataCollectorInterface;
use Drupal\Core\Controller\ControllerResolverInterface;
use Drupal\Core\Render\ElementInfoManagerInterface;
use Drupal\Core\Render\PlaceholderGeneratorInterface;
use Drupal\Core\Render\RenderCacheInterface;
use Drupal\Core\Render\Renderer;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\Theme\ThemeManagerInterface;
use Drupal\Core\Utility\CallableResolver;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Decorator of the service renderer.
 */
class RendererDecorator extends Renderer {

  /**
   * Original renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $originalRenderer;

  /**
   * Collector.
   *
   * @var \Drupal\cacheprofiler\DataCollector\CacheProfilerDataCollectorInterface
   */
  protected $profilerCollector;

  /**
   * Constructs a new Renderer.
   *
   * @param \Drupal\Core\Render\RendererInterface $originalRenderer
   *   The original renderer service.
   * @param \Drupal\Core\Utility\CallableResolver|\Drupal\Core\Controller\ControllerResolverInterface $callable_resolver
   *   The callable resolver.
   * @param \Drupal\Core\Theme\ThemeManagerInterface $theme
   *   The theme manager.
   * @param \Drupal\Core\Render\ElementInfoManagerInterface $element_info
   *   The element info.
   * @param \Drupal\Core\Render\PlaceholderGeneratorInterface $placeholder_generator
   *   The placeholder generator.
   * @param \Drupal\Core\Render\RenderCacheInterface $render_cache
   *   The render cache service.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   * @param array $renderer_config
   *   The renderer configuration array.
   * @param \Drupal\cacheprofiler\DataCollector\CacheProfilerDataCollectorInterface $profilerCollector
   *   The cache profiler data collector.
   */
  public function __construct(RendererInterface $originalRenderer, ControllerResolverInterface|CallableResolver $callable_resolver, ThemeManagerInterface $theme, ElementInfoManagerInterface $element_info, PlaceholderGeneratorInterface $placeholder_generator, RenderCacheInterface $render_cache, RequestStack $request_stack, array $renderer_config, CacheProfilerDataCollectorInterface $profilerCollector) {
    $this->originalRenderer = $originalRenderer;
    $this->profilerCollector = $profilerCollector;
    parent::__construct($callable_resolver, $theme, $element_info, $placeholder_generator, $render_cache, $request_stack, $renderer_config);
  }

  /**
   * {@inheritdoc}
   */
  public function render(&$elements, $is_root_call = FALSE) {
    return parent::render($elements, $is_root_call);
  }

}
